@@ -30,6 +30,18 @@ Normalized Mie scattering intensities for angles mu=cos(theta)::
     miepython.i_per(m, x, mu)
     miepython.i_par(m, x, mu)
     miepython.i_unpolarized(m, x, mu)
+
+Mie scattering intensities normalized to one when integrated over all angles::
+
+    miepython.i_per(m, x, mu, norm='one')
+    miepython.i_par(m, x, mu, norm='one')
+    miepython.i_unpolarized(m, x, mu, norm='one')
 """
+__version__ = '2.3.2'
+__author__ = 'Scott Prahl'
+__email__ = 'scott.prahl@oit.edu'
+__copyright__ = 'Copyright 2017-23, Scott Prahl'
+__license__ = 'MIT'
+__url__ = 'https://github.com/scottprahl/miepython.git'
 
 from .miepython import *
